
#include <iostream>
#include <sstream>
#include <string>
#include <vector>
#include <iterator>
#include <algorithm>

#include "SketchUpCollada.h"


/* Utility functions.... */

/* This function illustrates how you might convert the vectors to arrays if you are more comfortable working
 with those.    Note that each call to this function allocates an array.  Not disposing of these pointers will
 result in a memory leak.  */

float * convertVectorToArray(std::vector<float> floats) {
	int numElemsInVector = floats.size();
	float *arrayOfFloats = new float[numElemsInVector];  // Allocate new array to hold contents of vector
	for (int i=0; i<numElemsInVector; i++) // Copy elements from the vector into the array
		arrayOfFloats[i] = floats[i];
	return arrayOfFloats;
}
	
/* Prints the contents of a vector, preceded by given message.  Elements of vector are separated by commas.
 */
void printVector(const char* msg, std::vector<float> vec) {
	printf("%s",msg);
	if (vec.size() > 0) {
		printf("%f",vec[0]);
		for (int i=1; i<vec.size(); i++)
			printf(",%f",vec[i]);
	}
	printf("\n");
}


int main (int argc, char * const argv[]) {

	const char* pFilename = "2x4 rectangle.dae";
	std::vector<float> coordinates; // x,y,z coordinates of points defining the shape
	std::vector<int> pointsDefiningTriangles;
	std::vector<int> pointsDefiningEdges;
	SketchUpCollada colladaObject(pFilename);  // Load the file and grab its contents
	if (colladaObject.isLoadedFile())
	{
		coordinates = colladaObject.vertexCoordinates(); 
		pointsDefiningTriangles = colladaObject.triangleDefinitions(); 
		pointsDefiningEdges = colladaObject.edgeDefinitions(); 
		for(int i=0; i< coordinates.size(); i+=3)
			printf("Point p%d: (x,y,z)=(%f,%f,%f)\n", i/3, coordinates[i],coordinates[i+1],coordinates[i+2]);
		for(int i=0; i<pointsDefiningTriangles.size();i+=3)
			printf("Triangle #%d: (p%d, p%d, p%d)\n", i/3, pointsDefiningTriangles[i],pointsDefiningTriangles[i+1],pointsDefiningTriangles[i+2]);
		for(int i=0; i<pointsDefiningEdges.size();i+=2)
			printf("Edge #%d: (p%d, p%d)\n", i/2, pointsDefiningEdges[i],pointsDefiningEdges[i+1]);

	}
	else
	{
		printf("Failed to properly load collada file \"%s\"\n", pFilename);
		return 0;
	}
	
	return 0;
}
